from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SequenceCls:
	"""Sequence commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sequence", core, parent)

	# noinspection PyTypeChecker
	class SetStruct(StructBase):
		"""Structure for setting input parameters. Fields: \n
			- Frequency: float: No parameter help available
			- Rbw: float: No parameter help available
			- Meas_Time: float: No parameter help available
			- Trigger_Source: enums.TriggerSourceMpower: No parameter help available
			- Trigger_Level: float: No parameter help available
			- Trigger_Offset: float: No parameter help available
			- Detector: enums.MpowerDetector: No parameter help available
			- Of_Pulses: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_float('Frequency'),
			ArgStruct.scalar_float('Rbw'),
			ArgStruct.scalar_float('Meas_Time'),
			ArgStruct.scalar_enum('Trigger_Source', enums.TriggerSourceMpower),
			ArgStruct.scalar_float('Trigger_Level'),
			ArgStruct.scalar_float('Trigger_Offset'),
			ArgStruct.scalar_enum('Detector', enums.MpowerDetector),
			ArgStruct.scalar_float('Of_Pulses')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Frequency: float = None
			self.Rbw: float = None
			self.Meas_Time: float = None
			self.Trigger_Source: enums.TriggerSourceMpower = None
			self.Trigger_Level: float = None
			self.Trigger_Offset: float = None
			self.Detector: enums.MpowerDetector = None
			self.Of_Pulses: float = None

	def set(self, structure: SetStruct) -> None:
		"""SCPI: [SENSe]:MPOWer[:SEQuence] \n
		Snippet with structure: \n
		structure = driver.sense.mpower.sequence.SetStruct() \n
		structure.Frequency: float = 1.0 \n
		structure.Rbw: float = 1.0 \n
		structure.Meas_Time: float = 1.0 \n
		structure.Trigger_Source: enums.TriggerSourceMpower = enums.TriggerSourceMpower.EXT2 \n
		structure.Trigger_Level: float = 1.0 \n
		structure.Trigger_Offset: float = 1.0 \n
		structure.Detector: enums.MpowerDetector = enums.MpowerDetector.MEAN \n
		structure.Of_Pulses: float = 1.0 \n
		driver.sense.mpower.sequence.set(structure) \n
		No command help available \n
			:param structure: for set value, see the help for SetStruct structure arguments.
		"""
		self._core.io.write_struct(f'SENSe:MPOWer:SEQuence', structure)

	def get(self) -> List[float]:
		"""SCPI: [SENSe]:MPOWer[:SEQuence] \n
		Snippet: value: List[float] = driver.sense.mpower.sequence.get() \n
		No command help available \n
			:return: power_levels: No help available"""
		response = self._core.io.query_bin_or_ascii_float_list(f'SENSe:MPOWer:SEQuence?')
		return response



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LimitCls:
	"""Limit commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("limit", core, parent)

	def set(self, columns: enums.StatisticType, filename: str, store=repcap.Store.Default) -> None:
		"""SCPI: MMEMory:STORe<n>:TABLe:LIMit \n
		Snippet: driver.massMemory.store.table.limit.set(columns = enums.StatisticType.ALL, filename = '1', store = repcap.Store.Default) \n
		No command help available \n
			:param columns: No help available
			:param filename: No help available
			:param store: optional repeated capability selector. Default value: Pos1 (settable in the interface 'Store')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('columns', columns, DataType.Enum, enums.StatisticType), ArgSingle('filename', filename, DataType.String))
		store_cmd_val = self._cmd_group.get_repcap_cmd_value(store, repcap.Store)
		self._core.io.write(f'MMEMory:STORe{store_cmd_val}:TABLe:LIMit {param}'.rstrip())



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GimbalanceCls:
	"""Gimbalance commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("gimbalance", core, parent)

	def get(self, result_type: enums.ResultTypeStat, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:DDEMod:STATistic:GIMBalance \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.marker.function.ddemod.statistic.gimbalance.get(result_type = enums.ResultTypeStat.AVG, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the results of the Gain Imbalance error measurement of digital demodulation. The output values are
		the same as those provided in the 'Modulation Accuracy' table . \n
			:param result_type: none Gain imbalance error for current sweep AVG Average gain imbalance error over several sweeps RPE Peak gain imbalance error over several sweeps SDEV Standard deviation of gain imbalance error PCTL 95 percentile value of gain imbalance error
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: result: No help available"""
		param = Conversions.enum_scalar_to_str(result_type, enums.ResultTypeStat)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:DDEMod:STATistic:GIMBalance? {param}')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OscilloscopeCls:
	"""Oscilloscope commands group definition. 8 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("oscilloscope", core, parent)

	@property
	def alignment(self):
		"""alignment commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_alignment'):
			from .Alignment import AlignmentCls
			self._alignment = AlignmentCls(self._core, self._cmd_group)
		return self._alignment

	@property
	def idn(self):
		"""idn commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_idn'):
			from .Idn import IdnCls
			self._idn = IdnCls(self._core, self._cmd_group)
		return self._idn

	@property
	def ledState(self):
		"""ledState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ledState'):
			from .LedState import LedStateCls
			self._ledState = LedStateCls(self._core, self._cmd_group)
		return self._ledState

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def tcpip(self):
		"""tcpip commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tcpip'):
			from .Tcpip import TcpipCls
			self._tcpip = TcpipCls(self._core, self._cmd_group)
		return self._tcpip

	@property
	def vdevice(self):
		"""vdevice commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_vdevice'):
			from .Vdevice import VdeviceCls
			self._vdevice = VdeviceCls(self._core, self._cmd_group)
		return self._vdevice

	@property
	def vfirmware(self):
		"""vfirmware commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_vfirmware'):
			from .Vfirmware import VfirmwareCls
			self._vfirmware = VfirmwareCls(self._core, self._cmd_group)
		return self._vfirmware

	def clone(self) -> 'OscilloscopeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = OscilloscopeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LengthCls:
	"""Length commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("length", core, parent)

	def set(self, length: int) -> None:
		"""SCPI: TRACe:IQ:EGATe:LENGth \n
		Snippet: driver.applications.iqAnalyzer.trace.iq.egate.length.set(length = 1) \n
		This command defines the gate length for gated measurements with the I/Q analyzer. \n
			:param length: numeric value Max = (440 MS * sample rate/200MHz) -1 pretrigger samples defined by TRACe:IQ:SET; sample rate defined by method RsFswp.Applications.IqAnalyzer.Trace.Iq.SymbolRate.set) Range: 1…Max (samples)
		"""
		param = Conversions.decimal_value_to_str(length)
		self._core.io.write(f'TRACe:IQ:EGATe:LENGth {param}')

	def get(self) -> int:
		"""SCPI: TRACe:IQ:EGATe:LENGth \n
		Snippet: value: int = driver.applications.iqAnalyzer.trace.iq.egate.length.get() \n
		This command defines the gate length for gated measurements with the I/Q analyzer. \n
			:return: length: No help available"""
		response = self._core.io.query_str(f'TRACe:IQ:EGATe:LENGth?')
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DuplicateCls:
	"""Duplicate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("duplicate", core, parent)

	def set(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: INSTrument:CREate:DUPLicate \n
		Snippet: driver.instrument.create.duplicate.set() \n
		This command duplicates the currently selected channel, i.e creates a new channel of the same type and with the identical
		measurement settings. The name of the new channel is the same as the copied channel, extended by a consecutive number (e.
		g. 'IQAnalyzer' -> 'IQAnalyzer 2') . The channel to be duplicated must be selected first using the INST:SEL command. (See
		method RsFswp.Instrument.Select.set) . This command is not available if the MSRA primary channel is selected. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'INSTrument:CREate:DUPLicate', opc_timeout_ms)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FdErrorCls:
	"""FdError commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fdError", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:DDEMod:NORMalize:FDERror \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.normalize.fdError.set(state = False) \n
		This command defines whether the deviation error is compensated for when calculating the frequency error for FSK
		modulation. \n
			:param state: ON | 1 Scales the reference signal to the actual deviation of the measurement signal. OFF | 0 Uses the entered nominal deviation for the reference signal.
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:DDEMod:NORMalize:FDERror {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:DDEMod:NORMalize:FDERror \n
		Snippet: value: bool = driver.applications.k70Vsa.sense.ddemod.normalize.fdError.get() \n
		This command defines whether the deviation error is compensated for when calculating the frequency error for FSK
		modulation. \n
			:return: state: ON | 1 Scales the reference signal to the actual deviation of the measurement signal. OFF | 0 Uses the entered nominal deviation for the reference signal."""
		response = self._core.io.query_str(f'SENSe:DDEMod:NORMalize:FDERror?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SearchCls:
	"""Search commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("search", core, parent)

	def set(self, mark_real_imag: enums.MarkerRealImagB, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:SEARch \n
		Snippet: driver.applications.k70Vsa.calculate.marker.search.set(mark_real_imag = enums.MarkerRealImagB.IMAG, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command specifies whether the marker search works on the real or the imag trace (for all markers) . \n
			:param mark_real_imag: REAL | IMAG
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = Conversions.enum_scalar_to_str(mark_real_imag, enums.MarkerRealImagB)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:SEARch {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> enums.MarkerRealImagB:
		"""SCPI: CALCulate<n>:MARKer<m>:SEARch \n
		Snippet: value: enums.MarkerRealImagB = driver.applications.k70Vsa.calculate.marker.search.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command specifies whether the marker search works on the real or the imag trace (for all markers) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: mark_real_imag: REAL | IMAG"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:SEARch?')
		return Conversions.str_to_scalar_enum(response, enums.MarkerRealImagB)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RpointCls:
	"""Rpoint commands group definition. 4 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rpoint", core, parent)

	@property
	def maximum(self):
		"""maximum commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_maximum'):
			from .Maximum import MaximumCls
			self._maximum = MaximumCls(self._core, self._cmd_group)
		return self._maximum

	@property
	def x(self):
		"""x commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_x'):
			from .X import XCls
			self._x = XCls(self._core, self._cmd_group)
		return self._x

	@property
	def y(self):
		"""y commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_y'):
			from .Y import YCls
			self._y = YCls(self._core, self._cmd_group)
		return self._y

	def clone(self) -> 'RpointCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RpointCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FreferenceCls:
	"""Freference commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("freference", core, parent)

	def set(self, limits: enums.ReferenceMode) -> None:
		"""SCPI: [SENSe]:CREFerence:FREFerence \n
		Snippet: driver.applications.k50Spurious.sense.creference.freference.set(limits = enums.ReferenceMode.ABSolute) \n
		No command help available \n
			:param limits: ABSolute | RELative
		"""
		param = Conversions.enum_scalar_to_str(limits, enums.ReferenceMode)
		self._core.io.write(f'SENSe:CREFerence:FREFerence {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.ReferenceMode:
		"""SCPI: [SENSe]:CREFerence:FREFerence \n
		Snippet: value: enums.ReferenceMode = driver.applications.k50Spurious.sense.creference.freference.get() \n
		No command help available \n
			:return: limits: ABSolute | RELative"""
		response = self._core.io.query_str(f'SENSe:CREFerence:FREFerence?')
		return Conversions.str_to_scalar_enum(response, enums.ReferenceMode)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UnitCls:
	"""Unit commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("unit", core, parent)

	def set(self, measurement: enums.PwrMeasUnit, window=repcap.Window.Default, marker=repcap.Marker.Default, subBlock=repcap.SubBlock.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:POWer<sb>:RESult:UNIT \n
		Snippet: driver.calculate.marker.function.power.result.unit.set(measurement = enums.PwrMeasUnit.ABS, window = repcap.Window.Default, marker = repcap.Marker.Default, subBlock = repcap.SubBlock.Default) \n
		No command help available \n
			:param measurement: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Power')
		"""
		param = Conversions.enum_scalar_to_str(measurement, enums.PwrMeasUnit)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:POWer{subBlock_cmd_val}:RESult:UNIT {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default, subBlock=repcap.SubBlock.Default) -> enums.PwrMeasUnit:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:POWer<sb>:RESult:UNIT \n
		Snippet: value: enums.PwrMeasUnit = driver.calculate.marker.function.power.result.unit.get(window = repcap.Window.Default, marker = repcap.Marker.Default, subBlock = repcap.SubBlock.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Power')
			:return: measurement: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:POWer{subBlock_cmd_val}:RESult:UNIT?')
		return Conversions.str_to_scalar_enum(response, enums.PwrMeasUnit)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FactorCls:
	"""Factor commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("factor", core, parent)

	def set(self, link_factor: float) -> None:
		"""SCPI: [SENSe]:FREQuency:CENTer:STEP:LINK:FACTor \n
		Snippet: driver.sense.frequency.center.step.link.factor.set(link_factor = 1.0) \n
		This command defines a step size factor if the center frequency step size is coupled to the span or the resolution
		bandwidth. \n
			:param link_factor: 1 to 100 PCT Unit: PCT
		"""
		param = Conversions.decimal_value_to_str(link_factor)
		self._core.io.write(f'SENSe:FREQuency:CENTer:STEP:LINK:FACTor {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:FREQuency:CENTer:STEP:LINK:FACTor \n
		Snippet: value: float = driver.sense.frequency.center.step.link.factor.get() \n
		This command defines a step size factor if the center frequency step size is coupled to the span or the resolution
		bandwidth. \n
			:return: link_factor: No help available"""
		response = self._core.io.query_str(f'SENSe:FREQuency:CENTer:STEP:LINK:FACTor?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, filterPy=repcap.FilterPy.Default) -> None:
		"""SCPI: [SENSe]:FILTer<n>:LPASs[:STATe] \n
		Snippet: driver.sense.filterPy.lpass.state.set(state = False, filterPy = repcap.FilterPy.Default) \n
		This command turns a low pass filter for measurements on small carrier frequencies on and off.
			INTRO_CMD_HELP: Effects of using thelow pass filter: \n
			- Auto search feature is turned off ([SENSe:]ADJust:CONFigure:FREQuency:AUTosearch[:STATe]) .
			- Signal count is turned off ([SENSe:]ADJust:CONFigure:FREQuency:COUNt) .
			- The stop offset is limited to 20 % of the filter cut-off frequency ([SENSe:]FREQuency:STOP) .
			- DC coupling should be used for measurements on carrier frequencies below 1 MHz (method RsFswp.Applications.K30_NoiseFigure.InputPy.Coupling.set) . \n
			:param state: ON | OFF | 1 | 0 When you turn on the filter, you can define a cutoff frequency with [SENSe:]FILTer:LPASs:FREQuency:MANual.
			:param filterPy: optional repeated capability selector. Default value: Nr1 (settable in the interface 'FilterPy')
		"""
		param = Conversions.bool_to_str(state)
		filterPy_cmd_val = self._cmd_group.get_repcap_cmd_value(filterPy, repcap.FilterPy)
		self._core.io.write(f'SENSe:FILTer{filterPy_cmd_val}:LPASs:STATe {param}')

	def get(self, filterPy=repcap.FilterPy.Default) -> bool:
		"""SCPI: [SENSe]:FILTer<n>:LPASs[:STATe] \n
		Snippet: value: bool = driver.sense.filterPy.lpass.state.get(filterPy = repcap.FilterPy.Default) \n
		This command turns a low pass filter for measurements on small carrier frequencies on and off.
			INTRO_CMD_HELP: Effects of using thelow pass filter: \n
			- Auto search feature is turned off ([SENSe:]ADJust:CONFigure:FREQuency:AUTosearch[:STATe]) .
			- Signal count is turned off ([SENSe:]ADJust:CONFigure:FREQuency:COUNt) .
			- The stop offset is limited to 20 % of the filter cut-off frequency ([SENSe:]FREQuency:STOP) .
			- DC coupling should be used for measurements on carrier frequencies below 1 MHz (method RsFswp.Applications.K30_NoiseFigure.InputPy.Coupling.set) . \n
			:param filterPy: optional repeated capability selector. Default value: Nr1 (settable in the interface 'FilterPy')
			:return: state: ON | OFF | 1 | 0 When you turn on the filter, you can define a cutoff frequency with [SENSe:]FILTer:LPASs:FREQuency:MANual."""
		filterPy_cmd_val = self._cmd_group.get_repcap_cmd_value(filterPy, repcap.FilterPy)
		response = self._core.io.query_str(f'SENSe:FILTer{filterPy_cmd_val}:LPASs:STATe?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SingleCls:
	"""Single commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("single", core, parent)

	@property
	def coupled(self):
		"""coupled commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_coupled'):
			from .Coupled import CoupledCls
			self._coupled = CoupledCls(self._core, self._cmd_group)
		return self._coupled

	def set(self, frequency: float) -> None:
		"""SCPI: [SENSe]:FREQuency:SINGle \n
		Snippet: driver.applications.k30NoiseFigure.sense.frequency.single.set(frequency = 1.0) \n
		This command defines the frequency for single frequency measurements. \n
			:param frequency: The minimum and maximum frequency depend on the hardware. Refer to the datasheet for details. Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'SENSe:FREQuency:SINGle {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:FREQuency:SINGle \n
		Snippet: value: float = driver.applications.k30NoiseFigure.sense.frequency.single.get() \n
		This command defines the frequency for single frequency measurements. \n
			:return: frequency: The minimum and maximum frequency depend on the hardware. Refer to the datasheet for details. Unit: HZ"""
		response = self._core.io.query_str(f'SENSe:FREQuency:SINGle?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'SingleCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SingleCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImmediateCls:
	"""Immediate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	def set(self, outputConnector=repcap.OutputConnector.Default, triggerPort=repcap.TriggerPort.Default) -> None:
		"""SCPI: OUTPut<up>:TRIGger<tp>:PULSe:IMMediate \n
		Snippet: driver.applications.k30NoiseFigure.output.trigger.pulse.immediate.set(outputConnector = repcap.OutputConnector.Default, triggerPort = repcap.TriggerPort.Default) \n
		This command generates a pulse at the trigger output. \n
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
		"""
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		self._core.io.write(f'OUTPut{outputConnector_cmd_val}:TRIGger{triggerPort_cmd_val}:PULSe:IMMediate')

	def set_with_opc(self, outputConnector=repcap.OutputConnector.Default, triggerPort=repcap.TriggerPort.Default, opc_timeout_ms: int = -1) -> None:
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		"""SCPI: OUTPut<up>:TRIGger<tp>:PULSe:IMMediate \n
		Snippet: driver.applications.k30NoiseFigure.output.trigger.pulse.immediate.set_with_opc(outputConnector = repcap.OutputConnector.Default, triggerPort = repcap.TriggerPort.Default) \n
		This command generates a pulse at the trigger output. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'OUTPut{outputConnector_cmd_val}:TRIGger{triggerPort_cmd_val}:PULSe:IMMediate', opc_timeout_ms)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ShiftCls:
	"""Shift commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("shift", core, parent)

	def set(self, distance: float, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:UPPer:SHIFt \n
		Snippet: driver.applications.k30NoiseFigure.calculate.limit.upper.shift.set(distance = 1.0, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command moves a complete upper limit line vertically. Compared to defining an offset, this command actually changes
		the limit line definition points by the value you define. \n
			:param distance: Defines the distance that the limit line moves.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		param = Conversions.decimal_value_to_str(distance)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:UPPer:SHIFt {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HighCls:
	"""High commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("high", core, parent)

	def set(self, frequency: float) -> None:
		"""SCPI: [SENSe]:ADJust:CONFigure:FREQuency:LIMit:HIGH \n
		Snippet: driver.sense.adjust.configure.frequency.limit.high.set(frequency = 1.0) \n
		This command defines the upper limit of the frequency search range.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on the automatic signal search with [SENSe:]ADJust:CONFigure:FREQuency:AUTosearch[:STATe] \n
			:param frequency: numeric value Range: See data sheet , Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'SENSe:ADJust:CONFigure:FREQuency:LIMit:HIGH {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:ADJust:CONFigure:FREQuency:LIMit:HIGH \n
		Snippet: value: float = driver.sense.adjust.configure.frequency.limit.high.get() \n
		This command defines the upper limit of the frequency search range.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on the automatic signal search with [SENSe:]ADJust:CONFigure:FREQuency:AUTosearch[:STATe] \n
			:return: frequency: numeric value Range: See data sheet , Unit: Hz"""
		response = self._core.io.query_str(f'SENSe:ADJust:CONFigure:FREQuency:LIMit:HIGH?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SbandCls:
	"""Sband commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sband", core, parent)

	def set(self, sideband_pos: enums.SidebandPos) -> None:
		"""SCPI: [SENSe]:DDEMod:SBANd \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.sband.set(sideband_pos = enums.SidebandPos.INVerse) \n
		This command selects the sideband for the demodulation. Note that this command is maintained for compatibility reasons
		only. Use the SENS:SWAP:IQ command for new remote control programs (see [SENSe:]SWAPiq) . \n
			:param sideband_pos: NORMal | INVerse NORMal Normal (non-inverted) position INVerse Inverted position
		"""
		param = Conversions.enum_scalar_to_str(sideband_pos, enums.SidebandPos)
		self._core.io.write(f'SENSe:DDEMod:SBANd {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SidebandPos:
		"""SCPI: [SENSe]:DDEMod:SBANd \n
		Snippet: value: enums.SidebandPos = driver.applications.k70Vsa.sense.ddemod.sband.get() \n
		This command selects the sideband for the demodulation. Note that this command is maintained for compatibility reasons
		only. Use the SENS:SWAP:IQ command for new remote control programs (see [SENSe:]SWAPiq) . \n
			:return: sideband_pos: NORMal | INVerse NORMal Normal (non-inverted) position INVerse Inverted position"""
		response = self._core.io.query_str(f'SENSe:DDEMod:SBANd?')
		return Conversions.str_to_scalar_enum(response, enums.SidebandPos)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def set(self, result_type: enums.ResultTypeC) -> None:
		"""SCPI: [SENSe]:ADEMod:FM:OFFSet \n
		Snippet: driver.sense.ademod.fm.offset.set(result_type = enums.ResultTypeC.AVERage) \n
		No command help available \n
			:param result_type: No help available
		"""
		param = Conversions.enum_scalar_to_str(result_type, enums.ResultTypeC)
		self._core.io.write(f'SENSe:ADEMod:FM:OFFSet {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.ResultTypeC:
		"""SCPI: [SENSe]:ADEMod:FM:OFFSet \n
		Snippet: value: enums.ResultTypeC = driver.sense.ademod.fm.offset.get() \n
		No command help available \n
			:return: result_type: No help available"""
		response = self._core.io.query_str(f'SENSe:ADEMod:FM:OFFSet?')
		return Conversions.str_to_scalar_enum(response, enums.ResultTypeC)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HeaderCls:
	"""Header commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("header", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: FORMat:DEXPort:HEADer \n
		Snippet: driver.applications.k30NoiseFigure.formatPy.dexport.header.set(state = False) \n
		If enabled, additional instrument and measurement settings are included in the header of the export file for result data.
		If disabled, only the pure result data from the selected traces and tables is exported. \n
			:param state: ON | OFF | 0 | 1
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'FORMat:DEXPort:HEADer {param}')

	def get(self) -> bool:
		"""SCPI: FORMat:DEXPort:HEADer \n
		Snippet: value: bool = driver.applications.k30NoiseFigure.formatPy.dexport.header.get() \n
		If enabled, additional instrument and measurement settings are included in the header of the export file for result data.
		If disabled, only the pure result data from the selected traces and tables is exported. \n
			:return: state: ON | OFF | 0 | 1"""
		response = self._core.io.query_str(f'FORMat:DEXPort:HEADer?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DomainCls:
	"""Domain commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("domain", core, parent)

	def set(self, span_setting: enums.SpanSetting, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:CONTrol:DOMain \n
		Snippet: driver.calculate.limit.control.domain.set(span_setting = enums.SpanSetting.FREQuency, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command selects the domain of the limit line. \n
			:param span_setting: FREQuency | TIME FREQuency For limit lines that apply to a range of frequencies. TIME For limit lines that apply to a period of time. CURRent For limit lines that apply to a range of currents. VOLTage For limit lines that apply to a range of voltages.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		param = Conversions.enum_scalar_to_str(span_setting, enums.SpanSetting)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:CONTrol:DOMain {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> enums.SpanSetting:
		"""SCPI: CALCulate<n>:LIMit<li>:CONTrol:DOMain \n
		Snippet: value: enums.SpanSetting = driver.calculate.limit.control.domain.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command selects the domain of the limit line. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: span_setting: FREQuency | TIME FREQuency For limit lines that apply to a range of frequencies. TIME For limit lines that apply to a period of time. CURRent For limit lines that apply to a range of currents. VOLTage For limit lines that apply to a range of voltages."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:CONTrol:DOMain?')
		return Conversions.str_to_scalar_enum(response, enums.SpanSetting)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def set(self, freq: List[float], level: List[float]) -> None:
		"""SCPI: [SENSe]:CORRection:CVL:DATA \n
		Snippet: driver.applications.k50Spurious.sense.correction.cvl.data.set(freq = [1.1, 2.2, 3.3], level = [1.1, 2.2, 3.3]) \n
		This command defines the reference values of the selected conversion loss tables. The values are entered as a set of
		frequency/level pairs. A maximum of 50 frequency/level pairs may be entered. Before this command can be performed, the
		conversion loss table must be selected (see [SENSe:]CORRection:CVL:SELect) . This command is only available with option
		B21 (External Mixer) installed. \n
			:param freq: The frequencies have to be sent in ascending order. Unit: HZ
			:param level: Unit: DB
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('freq', freq, DataType.FloatList, None), ArgSingle.as_open_list('level', level, DataType.FloatList, None))
		self._core.io.write(f'SENSe:CORRection:CVL:DATA {param}'.rstrip())

	def get(self, freq: List[float], level: List[float]) -> List[float]:
		"""SCPI: [SENSe]:CORRection:CVL:DATA \n
		Snippet: value: List[float] = driver.applications.k50Spurious.sense.correction.cvl.data.get(freq = [1.1, 2.2, 3.3], level = [1.1, 2.2, 3.3]) \n
		This command defines the reference values of the selected conversion loss tables. The values are entered as a set of
		frequency/level pairs. A maximum of 50 frequency/level pairs may be entered. Before this command can be performed, the
		conversion loss table must be selected (see [SENSe:]CORRection:CVL:SELect) . This command is only available with option
		B21 (External Mixer) installed. \n
			:param freq: The frequencies have to be sent in ascending order. Unit: HZ
			:param level: Unit: DB
			:return: freq: The frequencies have to be sent in ascending order. Unit: HZ"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('freq', freq, DataType.FloatList, None), ArgSingle.as_open_list('level', level, DataType.FloatList, None))
		response = self._core.io.query_bin_or_ascii_float_list(f'SENSe:CORRection:CVL:DATA? {param}'.rstrip())
		return response



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BreakPyCls:
	"""BreakPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("breakPy", core, parent)

	def set(self, state: bool, rangePy=repcap.RangePy.Default) -> None:
		"""SCPI: [SENSe]:LIST:RANGe<ri>:BREak \n
		Snippet: driver.sense.listPy.range.breakPy.set(state = False, rangePy = repcap.RangePy.Default) \n
		No command help available \n
			:param state: No help available
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
		"""
		param = Conversions.bool_to_str(state)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		self._core.io.write(f'SENSe:LIST:RANGe{rangePy_cmd_val}:BREak {param}')

	def get(self, rangePy=repcap.RangePy.Default) -> bool:
		"""SCPI: [SENSe]:LIST:RANGe<ri>:BREak \n
		Snippet: value: bool = driver.sense.listPy.range.breakPy.get(rangePy = repcap.RangePy.Default) \n
		No command help available \n
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:return: state: No help available"""
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		response = self._core.io.query_str(f'SENSe:LIST:RANGe{rangePy_cmd_val}:BREak?')
		return Conversions.str_to_bool(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FtypeCls:
	"""Ftype commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ftype", core, parent)

	def set(self, filter_type: enums.FilterTypeC) -> None:
		"""SCPI: [SENSe]:MPOWer:FTYPe \n
		Snippet: driver.sense.mpower.ftype.set(filter_type = enums.FilterTypeC.CFILter) \n
		No command help available \n
			:param filter_type: No help available
		"""
		param = Conversions.enum_scalar_to_str(filter_type, enums.FilterTypeC)
		self._core.io.write(f'SENSe:MPOWer:FTYPe {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FilterTypeC:
		"""SCPI: [SENSe]:MPOWer:FTYPe \n
		Snippet: value: enums.FilterTypeC = driver.sense.mpower.ftype.get() \n
		No command help available \n
			:return: filter_type: No help available"""
		response = self._core.io.query_str(f'SENSe:MPOWer:FTYPe?')
		return Conversions.str_to_scalar_enum(response, enums.FilterTypeC)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IqCls:
	"""Iq commands group definition. 22 total commands, 13 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("iq", core, parent)

	@property
	def apcon(self):
		"""apcon commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_apcon'):
			from .Apcon import ApconCls
			self._apcon = ApconCls(self._core, self._cmd_group)
		return self._apcon

	@property
	def tpiSample(self):
		"""tpiSample commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tpiSample'):
			from .TpiSample import TpiSampleCls
			self._tpiSample = TpiSampleCls(self._core, self._cmd_group)
		return self._tpiSample

	@property
	def average(self):
		"""average commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_average'):
			from .Average import AverageCls
			self._average = AverageCls(self._core, self._cmd_group)
		return self._average

	@property
	def diqFilter(self):
		"""diqFilter commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_diqFilter'):
			from .DiqFilter import DiqFilterCls
			self._diqFilter = DiqFilterCls(self._core, self._cmd_group)
		return self._diqFilter

	@property
	def egate(self):
		"""egate commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_egate'):
			from .Egate import EgateCls
			self._egate = EgateCls(self._core, self._cmd_group)
		return self._egate

	@property
	def eval(self):
		"""eval commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_eval'):
			from .Eval import EvalCls
			self._eval = EvalCls(self._core, self._cmd_group)
		return self._eval

	@property
	def wband(self):
		"""wband commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_wband'):
			from .Wband import WbandCls
			self._wband = WbandCls(self._core, self._cmd_group)
		return self._wband

	@property
	def wfilter(self):
		"""wfilter commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_wfilter'):
			from .Wfilter import WfilterCls
			self._wfilter = WfilterCls(self._core, self._cmd_group)
		return self._wfilter

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def file(self):
		"""file commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_file'):
			from .File import FileCls
			self._file = FileCls(self._core, self._cmd_group)
		return self._file

	@property
	def rlength(self):
		"""rlength commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rlength'):
			from .Rlength import RlengthCls
			self._rlength = RlengthCls(self._core, self._cmd_group)
		return self._rlength

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRateCls
			self._symbolRate = SymbolRateCls(self._core, self._cmd_group)
		return self._symbolRate

	@property
	def data(self):
		"""data commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	def clone(self) -> 'IqCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = IqCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, single_value: enums.SingleValue, window=repcap.Window.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:ITEM[:LINE][:VALue] \n
		Snippet: driver.applications.k70Vsa.display.window.item.line.value.set(single_value = enums.SingleValue.ALL, window = repcap.Window.Default) \n
		This commands switches between the whole 'Result Summary' and the diagram showing only a single value, e.g. the EVM RMS
		value as a bargraph. The same parameters are available as those for which modulation accuracy limits can be defined (see
		'Limit Value') . \n
			:param single_value: ALL | EVMR | EVMP | PERM | PEP | MERM | MEP | CFER | RHO | IQOF | FERM | FEP | FDER ALL Complete 'Result Summary' EVMR RMS EVM EVMP Peak EVM PERM RMS Phase error PEP Peak phase error MERM RMS Magnitude error MEP Peak magnitude error CFER Carrier frequency error RHO RHO IQOF I/Q offset FERM RMS frequency error FEP Peak frequency error FDER FSK deviation error
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = Conversions.enum_scalar_to_str(single_value, enums.SingleValue)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:ITEM:LINE:VALue {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default) -> enums.SingleValue:
		"""SCPI: DISPlay[:WINDow<n>]:ITEM[:LINE][:VALue] \n
		Snippet: value: enums.SingleValue = driver.applications.k70Vsa.display.window.item.line.value.get(window = repcap.Window.Default) \n
		This commands switches between the whole 'Result Summary' and the diagram showing only a single value, e.g. the EVM RMS
		value as a bargraph. The same parameters are available as those for which modulation accuracy limits can be defined (see
		'Limit Value') . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:return: single_value: ALL | EVMR | EVMP | PERM | PEP | MERM | MEP | CFER | RHO | IQOF | FERM | FEP | FDER ALL Complete 'Result Summary' EVMR RMS EVM EVMP Peak EVM PERM RMS Phase error PEP Peak phase error MERM RMS Magnitude error MEP Peak magnitude error CFER Carrier frequency error RHO RHO IQOF I/Q offset FERM RMS frequency error FEP Peak frequency error FDER FSK deviation error"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:ITEM:LINE:VALue?')
		return Conversions.str_to_scalar_enum(response, enums.SingleValue)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HarmonicCls:
	"""Harmonic commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("harmonic", core, parent)

	def set(self, harm_order: float) -> None:
		"""SCPI: [SENSe]:CORRection:CVL:HARMonic \n
		Snippet: driver.sense.correction.cvl.harmonic.set(harm_order = 1.0) \n
		This command defines the harmonic order for which the conversion loss table is to be used. This setting is checked
		against the current mixer setting before the table can be assigned to the range. Before this command can be performed,
		the conversion loss table must be selected (see [SENSe:]CORRection:CVL:SELect. This command is only available with option
		B21 (External Mixer) installed. \n
			:param harm_order: Range: 2 to 65
		"""
		param = Conversions.decimal_value_to_str(harm_order)
		self._core.io.write(f'SENSe:CORRection:CVL:HARMonic {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:CORRection:CVL:HARMonic \n
		Snippet: value: float = driver.sense.correction.cvl.harmonic.get() \n
		This command defines the harmonic order for which the conversion loss table is to be used. This setting is checked
		against the current mixer setting before the table can be assigned to the range. Before this command can be performed,
		the conversion loss table must be selected (see [SENSe:]CORRection:CVL:SELect. This command is only available with option
		B21 (External Mixer) installed. \n
			:return: harm_order: Range: 2 to 65"""
		response = self._core.io.query_str(f'SENSe:CORRection:CVL:HARMonic?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LinkCls:
	"""Link commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("link", core, parent)

	def set(self, mode: enums.GeneratorLink) -> None:
		"""SCPI: SYSTem:COMMunicate:RDEVice:GENerator:LINK \n
		Snippet: driver.applications.k30NoiseFigure.system.communicate.rdevice.generator.link.set(mode = enums.GeneratorLink.GPIB) \n
		No command help available \n
			:param mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.GeneratorLink)
		self._core.io.write(f'SYSTem:COMMunicate:RDEVice:GENerator:LINK {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.GeneratorLink:
		"""SCPI: SYSTem:COMMunicate:RDEVice:GENerator:LINK \n
		Snippet: value: enums.GeneratorLink = driver.applications.k30NoiseFigure.system.communicate.rdevice.generator.link.get() \n
		No command help available \n
			:return: mode: No help available"""
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:GENerator:LINK?')
		return Conversions.str_to_scalar_enum(response, enums.GeneratorLink)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpectrumCls:
	"""Spectrum commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("spectrum", core, parent)

	def set(self, bandwidth: enums.ServiceBandwidth) -> None:
		"""SCPI: DIAGnostic:SERVice:INPut:RF[:SPECtrum] \n
		Snippet: driver.diagnostic.service.inputPy.rf.spectrum.set(bandwidth = enums.ServiceBandwidth.BROadband) \n
		This command selects the bandwidth of the calibration signal. \n
			:param bandwidth: NARRowband | BROadband NARRowband Narrowband signal for power calibration of the frontend. BROadband Broadband signal for calibration of the IF filter.
		"""
		param = Conversions.enum_scalar_to_str(bandwidth, enums.ServiceBandwidth)
		self._core.io.write(f'DIAGnostic:SERVice:INPut:RF:SPECtrum {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.ServiceBandwidth:
		"""SCPI: DIAGnostic:SERVice:INPut:RF[:SPECtrum] \n
		Snippet: value: enums.ServiceBandwidth = driver.diagnostic.service.inputPy.rf.spectrum.get() \n
		This command selects the bandwidth of the calibration signal. \n
			:return: bandwidth: NARRowband | BROadband NARRowband Narrowband signal for power calibration of the frontend. BROadband Broadband signal for calibration of the IF filter."""
		response = self._core.io.query_str(f'DIAGnostic:SERVice:INPut:RF:SPECtrum?')
		return Conversions.str_to_scalar_enum(response, enums.ServiceBandwidth)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	def set(self, frequency: float, externalRosc=repcap.ExternalRosc.Nr1) -> None:
		"""SCPI: SOURce:EXTernal<ext>:ROSCillator:EXTernal:FREQuency \n
		Snippet: driver.source.external.roscillator.external.frequency.set(frequency = 1.0, externalRosc = repcap.ExternalRosc.Nr1) \n
		This command defines the frequency of the external reference oscillator. If the external reference oscillator is selected,
		the reference signal must be connected to the rear panel of the instrument. \n
			:param frequency: Range: 1 MHz to 50 MHz, Unit: HZ
			:param externalRosc: optional repeated capability selector. Default value: Nr1
		"""
		param = Conversions.decimal_value_to_str(frequency)
		externalRosc_cmd_val = self._cmd_group.get_repcap_cmd_value(externalRosc, repcap.ExternalRosc)
		self._core.io.write(f'SOURce:EXTernal{externalRosc_cmd_val}:ROSCillator:EXTernal:FREQuency {param}')

	def get(self, externalRosc=repcap.ExternalRosc.Nr1) -> float:
		"""SCPI: SOURce:EXTernal<ext>:ROSCillator:EXTernal:FREQuency \n
		Snippet: value: float = driver.source.external.roscillator.external.frequency.get(externalRosc = repcap.ExternalRosc.Nr1) \n
		This command defines the frequency of the external reference oscillator. If the external reference oscillator is selected,
		the reference signal must be connected to the rear panel of the instrument. \n
			:param externalRosc: optional repeated capability selector. Default value: Nr1
			:return: frequency: Range: 1 MHz to 50 MHz, Unit: HZ"""
		externalRosc_cmd_val = self._cmd_group.get_repcap_cmd_value(externalRosc, repcap.ExternalRosc)
		response = self._core.io.query_str(f'SOURce:EXTernal{externalRosc_cmd_val}:ROSCillator:EXTernal:FREQuency?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'FrequencyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FrequencyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AlgorithmCls:
	"""Algorithm commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("algorithm", core, parent)

	def set(self, algorithm: enums.SummaryMode) -> None:
		"""SCPI: [SENSe]:IQ:FFT:ALGorithm \n
		Snippet: driver.applications.iqAnalyzer.sense.iq.fft.algorithm.set(algorithm = enums.SummaryMode.AVERage) \n
		Defines the FFT calculation method. For more information see 'Basics on FFT'. \n
			:param algorithm: SINGle One FFT is calculated for the entire record length; if the FFT length is larger than the record length (see [SENSe:]IQ:FFT:LENGth and method RsFswp.Applications.IqAnalyzer.Trace.Iq.Rlength.set) , zeros are appended to the captured data. AVERage Several overlapping FFTs are calculated for each record; the results are averaged to determine the final FFT result for the record. The user-defined window length and window overlap are used (see [SENSe:]IQ:FFT:WINDow:LENGth and [SENSe:]IQ:FFT:WINDow:OVERlap) .
		"""
		param = Conversions.enum_scalar_to_str(algorithm, enums.SummaryMode)
		self._core.io.write(f'SENSe:IQ:FFT:ALGorithm {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SummaryMode:
		"""SCPI: [SENSe]:IQ:FFT:ALGorithm \n
		Snippet: value: enums.SummaryMode = driver.applications.iqAnalyzer.sense.iq.fft.algorithm.get() \n
		Defines the FFT calculation method. For more information see 'Basics on FFT'. \n
			:return: algorithm: No help available"""
		response = self._core.io.query_str(f'SENSe:IQ:FFT:ALGorithm?')
		return Conversions.str_to_scalar_enum(response, enums.SummaryMode)
